pub struct ThreadInstructionRemove {
pub index: u64,
}Expand description
Instruction.
Fields
index: u64Trait Implementations
Sourceimpl BorshDeserialize for ThreadInstructionRemovewhere
u64: BorshDeserialize,
impl BorshDeserialize for ThreadInstructionRemovewhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ThreadInstructionRemovewhere
u64: BorshSerialize,
impl BorshSerialize for ThreadInstructionRemovewhere
u64: BorshSerialize,
Sourceimpl Discriminator for ThreadInstructionRemove
impl Discriminator for ThreadInstructionRemove
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]