pub struct ThreadSettings {
pub fee: Option<u64>,
pub instructions: Option<Vec<SerializableInstruction>>,
pub name: Option<String>,
pub rate_limit: Option<u64>,
pub trigger: Option<Trigger>,
}Expand description
The properties of threads which are updatable.
Fields
fee: Option<u64>instructions: Option<Vec<SerializableInstruction>>name: Option<String>rate_limit: Option<u64>trigger: Option<Trigger>Trait Implementations
Sourceimpl BorshDeserialize for ThreadSettings
impl BorshDeserialize for ThreadSettings
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ThreadSettingswhere
Option<u64>: BorshSerialize,
Option<Vec<SerializableInstruction>>: BorshSerialize,
Option<String>: BorshSerialize,
Option<Trigger>: BorshSerialize,
impl BorshSerialize for ThreadSettingswhere
Option<u64>: BorshSerialize,
Option<Vec<SerializableInstruction>>: BorshSerialize,
Option<String>: BorshSerialize,
Option<Trigger>: BorshSerialize,